# ReinspectionSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**inspection_date** | **datetime** |  | 
**work_reference_number** | **str** |  | 
**location_description** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**inspection_type** | [**InspectionTypeResponse**](InspectionTypeResponse.md) |  | 
**inspection_type_string** | **str** |  | 
**inspection_category** | **AllOfReinspectionSummaryResponseInspectionCategory** |  | [optional] 
**inspection_category_string** | **str** |  | [optional] 
**highway_authority** | **str** |  | 
**promoter_organisation** | **str** |  | 
**date_modified** | **datetime** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

